@@ -36,7 +36,7 @@ extern PyTypeObject PyGIRepository_Type;
 
 extern PyObject *PyGIRepositoryError;
 
-void _pygi_repository_register_types (PyObject *m);
+int pygi_repository_register_types (PyObject *m);
 
 G_END_DECLS
 
