@@ -24,8 +24,8 @@
 #ifndef __PYGI_SOURCE_H__
 #define __PYGI_SOURCE_H__
 
-PyObject *pyg_source_new (void);
-PyObject *pyg_source_set_callback (PyGObject *self, PyObject *args);
+PyObject *pygi_source_new (PyObject *self, PyObject *args);
+PyObject *pygi_source_set_callback (PyGObject *self, PyObject *args);
 
 #endif /* __PYGI_SOURCE_H__ */
 
