@@ -33,6 +33,6 @@ void pyg_register_interface(PyObject *dict,
 const GInterfaceInfo * pyg_lookup_interface_info(GType gtype);
 void pyg_register_interface_info(GType gtype, const
 				 GInterfaceInfo *info);
-void pygobject_interface_register_types(PyObject *d);
+int pygi_interface_register_types(PyObject *d);
 
 #endif /* __PYGOBJECT_INTERFACE_H__ */
