@@ -1,39 +1,12 @@
 import os
 import sys
-import unittest
 import signal
 import subprocess
 import atexit
 import warnings
-import imp
-
-
-class GIImport:
-    def find_module(self, fullname, path=None):
-        if fullname in ('gi._gi', 'gi._gi_cairo'):
-            return self
-        return None
-
-    def load_module(self, name):
-        if name in sys.modules:
-            return sys.modules[name]
-        fp, pathname, description = imp.find_module(name.split('.')[-1])
-        try:
-            module = imp.load_module(name, fp, pathname, description)
-        finally:
-            if fp:
-                fp.close()
-        sys.modules[name] = module
-        return module
-
-
-sys.meta_path.insert(0, GIImport())
 
 
 def init_test_environ():
-    # this was renamed in Python 3, provide backwards compatible name
-    unittest.TestCase.assertRegexpMatches = unittest.TestCase.assertRegex
-    unittest.TestCase.assertRaisesRegexp = unittest.TestCase.assertRaisesRegex
 
     def dbus_launch_session():
         if os.name == "nt" or sys.platform == "darwin":
@@ -85,6 +58,10 @@ def init_test_environ():
     # Avoid accessibility dbus warnings
     os.environ['NO_AT_BRIDGE'] = '1'
 
+    # A workaround for https://gitlab.gnome.org/GNOME/glib/-/issues/2251
+    # The gtk4 a11y stack calls get_dbus_object_path() on the default app
+    os.environ['GTK_A11Y'] = 'none'
+
     # Force the default theme so broken themes don't affect the tests
     os.environ['GTK_THEME'] = 'Adwaita'
 
@@ -93,7 +70,6 @@ def init_test_environ():
     from gi.repository import GIRepository
     repo = GIRepository.Repository.get_default()
     repo.prepend_library_path(os.path.join(tests_builddir))
-    repo.prepend_library_path(os.path.join(tests_builddir, ".libs"))
     repo.prepend_search_path(tests_builddir)
 
     def try_require_version(namespace, version):
