@@ -1,7 +1,4 @@
 # -*- Mode: Python -*-
-# encoding: UTF-8
-
-from __future__ import absolute_import
 
 import os
 import sys
@@ -14,12 +11,10 @@ import pytest
 from gi.repository import GLib
 from gi import PyGIDeprecationWarning
 
-from .compathelper import PY3
-
 
 class TestGLib(unittest.TestCase):
 
-    @pytest.mark.xfail(strict=True)
+    @pytest.mark.xfail()
     def test_pytest_capture_error_in_closure(self):
         # this test is supposed to fail
         ml = GLib.MainLoop()
@@ -84,12 +79,8 @@ class TestGLib(unittest.TestCase):
             if isinstance(f, bytes):
                 return f
             if os.name == "nt":
-                if PY3:
-                    return f.encode("utf-8", "surrogatepass")
-                else:
-                    return f.encode("utf-8")
+                return f.encode("utf-8", "surrogatepass")
             else:
-                assert PY3
                 return os.fsencode(f)
 
         # this is locale dependent, so we cannot completely verify the result
