@@ -1,11 +1,9 @@
 # -*- Mode: Python -*-
 
-from __future__ import absolute_import
-
 import unittest
 
 from gi.repository import GObject
-from . import testhelper
+import testhelper
 
 
 GUnknown = GObject.type_from_name("TestUnknown")
