@@ -1,12 +1,10 @@
 # -*- Mode: Python -*-
 
-from __future__ import absolute_import
-
 import unittest
 
 from gi.repository import GLib
 
-from . import testhelper
+import testhelper
 
 
 class TestThread(unittest.TestCase):
