@@ -5,7 +5,12 @@
 #include "test-unknown.h"
 #include "test-floating.h"
 
-#include "pygi-python-compat.h"
+#define PYGI_DEFINE_TYPE(typename, symbol, csymbol)	\
+PyTypeObject symbol = {                                 \
+    PyVarObject_HEAD_INIT(NULL, 0)                      \
+    typename,                                           \
+    sizeof(csymbol)                                     \
+};
 
 static PyObject * _wrap_TestInterface__do_iface_method(PyObject *cls,
 						       PyObject *args,
@@ -82,7 +87,7 @@ _wrap_test_g_object_new (PyObject * self)
     PyObject *rv;
 
     obj = g_object_new(g_type_from_name("PyGObject"), NULL);
-    rv = PYGLIB_PyLong_FromLong(obj->ref_count); /* should be == 2 at this point */
+    rv = PyLong_FromLong(obj->ref_count); /* should be == 2 at this point */
     g_object_unref(obj);
     return rv;
 }
@@ -111,7 +116,7 @@ static const PyMethodDef _PyTestInterface_methods[] = {
 };
 
 /* TestInterface */
-PYGLIB_DEFINE_TYPE("test.Interface", PyTestInterface_Type, PyObject);
+PYGI_DEFINE_TYPE("test.Interface", PyTestInterface_Type, PyObject);
 
 static PyObject *
 _wrap_TestInterface__do_iface_method(PyObject *cls, PyObject *args, PyObject *kwargs)
@@ -136,7 +141,7 @@ _wrap_TestInterface__do_iface_method(PyObject *cls, PyObject *args, PyObject *kw
   return Py_None;
 }
 
-PYGLIB_DEFINE_TYPE("testhelper.Unknown", PyTestUnknown_Type, PyGObject);
+PYGI_DEFINE_TYPE("testhelper.Unknown", PyTestUnknown_Type, PyGObject);
 
 static void
 _wrap_TestInterface__proxy_do_iface_method(TestInterface *self)
@@ -222,10 +227,10 @@ static const GInterfaceInfo __TestInterface__iinfo = {
 };
 
 /* TestFloating */
-PYGLIB_DEFINE_TYPE("testhelper.Floating", PyTestFloating_Type, PyGObject);
+PYGI_DEFINE_TYPE("testhelper.Floating", PyTestFloating_Type, PyGObject);
 
 /* TestOwnedByLibrary */
-PYGLIB_DEFINE_TYPE("testhelper.OwnedByLibrary", PyTestOwnedByLibrary_Type, PyGObject);
+PYGI_DEFINE_TYPE("testhelper.OwnedByLibrary", PyTestOwnedByLibrary_Type, PyGObject);
 
 static PyObject *
 _wrap_test_owned_by_library_release (PyGObject *self)
@@ -240,7 +245,7 @@ static const PyMethodDef _PyTestOwnedByLibrary_methods[] = {
 };
 
 /* TestFloatingAndSunk */
-PYGLIB_DEFINE_TYPE("testhelper.FloatingAndSunk", PyTestFloatingAndSunk_Type, PyGObject);
+PYGI_DEFINE_TYPE("testhelper.FloatingAndSunk", PyTestFloatingAndSunk_Type, PyGObject);
 
 static PyObject *
 _wrap_test_floating_and_sunk_release (PyGObject *self)
@@ -357,11 +362,12 @@ test_paramspec_callback (GObject *object)
 static GValue *
 test_gvalue_callback (GObject *object, const GValue *v)
 {
-  GValue *ret = g_malloc0 (sizeof (GValue));
+  GValue *ret;
 
   g_return_val_if_fail (G_IS_OBJECT (object), NULL);
   g_return_val_if_fail (G_IS_VALUE (v), NULL);
 
+  ret = g_malloc0 (sizeof (GValue));
   g_value_init (ret, G_VALUE_TYPE (v));
   g_value_copy (v, ret);
   return ret;
@@ -370,10 +376,11 @@ test_gvalue_callback (GObject *object, const GValue *v)
 static GValue *
 test_gvalue_ret_callback (GObject *object, GType type)
 {
-  GValue *ret = g_malloc0 (sizeof (GValue));
+  GValue *ret;
 
   g_return_val_if_fail (G_IS_OBJECT (object), NULL);
 
+  ret = g_malloc0 (sizeof (GValue));
   g_value_init (ret, type);
 
   switch (type) {
@@ -513,6 +520,8 @@ _wrap_test_state_ensure_release(PyObject *self, PyObject *args)
     Py_RETURN_NONE;
 }
 
+#define PYGI_TYPE_VALUE_ARRAY (g_value_array_get_type())
+
 static PyObject *
 _wrap_test_value_array(PyObject *self, PyObject *args)
 {
@@ -523,7 +532,7 @@ _wrap_test_value_array(PyObject *self, PyObject *args)
     return NULL;
 
   G_GNUC_BEGIN_IGNORE_DEPRECATIONS
-  g_value_init(value, G_TYPE_VALUE_ARRAY);
+  g_value_init(value, PYGI_TYPE_VALUE_ARRAY);
   G_GNUC_END_IGNORE_DEPRECATIONS
 
   if (pyg_value_from_pyobject(value, obj)) {
@@ -550,9 +559,9 @@ _wrap_value_array_get_nth_type(PyObject *self, PyObject *args)
   G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 
   if (pyg_boxed_check(obj, G_TYPE_VALUE) &&
-      G_VALUE_HOLDS(pyg_boxed_get(obj, GValue), G_TYPE_VALUE_ARRAY)) {
+      G_VALUE_HOLDS(pyg_boxed_get(obj, GValue), PYGI_TYPE_VALUE_ARRAY)) {
     arr = g_value_get_boxed(pyg_boxed_get(obj, GValue));
-  } else if (pyg_boxed_check(obj, G_TYPE_VALUE_ARRAY)) {
+  } else if (pyg_boxed_check(obj, PYGI_TYPE_VALUE_ARRAY)) {
     arr = pyg_boxed_get(obj, GValueArray);
   } else {
     PyErr_SetString(PyExc_TypeError, "First argument is not GValueArray");
@@ -581,7 +590,7 @@ _wrap_constant_strip_prefix(PyObject *self, PyObject *args)
         return NULL;
 
     result = pyg_constant_strip_prefix (name, strip_prefix);
-    return PYGLIB_PyUnicode_FromString (result);
+    return PyUnicode_FromString (result);
 }
 
 static PyObject *
@@ -655,6 +664,7 @@ _wrap_test_floating_and_sunk_get_instance_list (PyObject *self)
     return py_list;
 }
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 
 static PyObject *
 _wrap_test_parse_constructor_args (PyObject *self, PyObject *args)
@@ -673,9 +683,11 @@ _wrap_test_parse_constructor_args (PyObject *self, PyObject *args)
         return NULL;
     }
 
-    return PYGLIB_PyLong_FromLong (nparams);
+    return PyLong_FromLong (nparams);
 }
 
+G_GNUC_END_IGNORE_DEPRECATIONS
+
 static PyObject *
 _wrap_test_to_unichar_conv (PyObject * self, PyObject *args)
 {
@@ -688,7 +700,7 @@ _wrap_test_to_unichar_conv (PyObject * self, PyObject *args)
     if (!pyg_pyobj_to_unichar_conv (obj, &result))
         return NULL;
 
-    return PYGLIB_PyLong_FromLong (result);
+    return PyLong_FromLong (result);
 }
 
 static PyMethodDef testhelper_functions[] = {
@@ -710,11 +722,32 @@ static PyMethodDef testhelper_functions[] = {
     { NULL, NULL }
 };
 
-PYGLIB_MODULE_START(testhelper, "testhelper")
-{
+static struct PyModuleDef _testhelpermodule = {
+    PyModuleDef_HEAD_INIT,
+    "testhelper",
+    NULL,
+    -1,
+    testhelper_functions,
+    NULL,
+    NULL,
+    NULL,
+    NULL
+};
+
+#ifdef __GNUC__
+#define PYGI_MODINIT_FUNC __attribute__((visibility("default"))) PyMODINIT_FUNC
+#else
+#define PYGI_MODINIT_FUNC PyMODINIT_FUNC
+#endif
+
+PYGI_MODINIT_FUNC PyInit_testhelper(void);
+
+PYGI_MODINIT_FUNC PyInit_testhelper(void) {
+  PyObject *module;
   PyObject *gobject_module;
   PyObject *m, *d;
 
+  module = PyModule_Create(&_testhelpermodule);
 
   if ((gobject_module = pygobject_init(-1, -1, -1)) == NULL)
     return NULL;
@@ -725,7 +758,7 @@ PYGLIB_MODULE_START(testhelper, "testhelper")
   if ((m = PyImport_ImportModule("gi.repository.GObject")) == NULL) {
     PyErr_SetString(PyExc_ImportError,
 		    "could not import gobject");
-    return PYGLIB_MODULE_ERROR_RETURN;
+    return NULL;
   }
 
   /* TestInterface */
@@ -774,6 +807,7 @@ PYGLIB_MODULE_START(testhelper, "testhelper")
                            &PyTestFloatingAndSunk_Type,
                            Py_BuildValue("(O)",
                            &PyGObject_Type));
+
+  return module;
 }
-PYGLIB_MODULE_END
 
